import json
import os
import requests
import time

from lcapi.config import config

def show_lists():
  print ("Retreiving available lists ...")
  ## make our request
  req = requests.post(f"{config.url}&api2&get=lists_list", data=config.key)
  
  if req.status_code == 200:
    ## if we are successful, loop through the results
    lsts = json.loads(req.text)
    for ls in lsts['result']:
      print(f"{ls['name']}\t{ls['type']}")
  else:
    ## if we fail, show the error
    msg = json.loads(req.text)
    print (f"Error: {msg['error']}")

def download(ls, typ, outfile):
  if ls == "all":
    ls = f"{typ}_all"
  elif ls in config.lists:
    ls = config.lists[ls]

  print(f"Downloading {ls}.{typ}.txt ...")
  req = requests.post(f"{config.url}&download={typ}&file={ls}", data=config.key)
   
  #if req.status_code == 200:
  ## lc doesn't support error codes yet, let's work around this
  try:
    err = json.loads(req.text)
  except json.decoder.JSONDecodeError as e:
    err = None
  if not err:
    ## if successful, save our files
    if outfile:
      open(outfile, 'ab').write(req.content)
    else:
      open(f"{ls}.{typ}.txt", 'wb').write(req.content)
  else:
    ## if we fail, show the error
    msg = json.loads(req.text)
    print (f"Error: {msg['error']}")

def upload(ls, infile, watch):
  ## expand out path before processing
  infile = os.path.abspath(os.path.expanduser(infile))

  last_mtime=0
  while True:
    ## when looping, only upload if the infile has been modified since last check
    mtime = os.path.getmtime(infile)
    if mtime == last_mtime:
      continue
    last_time = mtime
    
    print(f"Uploading to {ls} ...")
    ## select our file to upload
    files = {'file': open(infile, 'rb')}
    ## upload!
    req = requests.post(f"{config.url}&uploadlistname={ls}", data=config.key, files=files)
    ## dump our response
    msg = json.loads(req.text)
    if msg['message']:
      print(msg['message'])
    else:
      print(f"Error: {msg['error']}")
    if not watch:
      break
    time.sleep(float(config.delay))



#!/bin/env python3

import argparse
import pkg_resources
import sys
import time

import lcapi.commands
from lcapi.config import config

############################################################
## Version Check

if (sys.version_info < (3, 0)):
  sys.stderr.write("[!] Error! Must execute this script with Python3.")
  sys.exit(2)

############################################################
## Parse options

parser = argparse.ArgumentParser(
    description='CLI client for the lc API.')
parser.add_argument('--delay',
                    dest='delay',
                    action='store',
                    type=float,
                    help='delay between uploads')
parser.add_argument('-d', '--download',
                    dest='download',
                    action='store_true',
                    help='download a list')
parser.add_argument('--lists',
                    dest='lists',
                    action='store_true',
                    help='show all available lists')
parser.add_argument('-o',
                    dest='outfile',
                    action='store',
                    default=None,
                    help='append downloads to <OUTFILE>')
parser.add_argument('-t', '--type',
                    dest='type',
                    action='store',
                    nargs='?',
                    default='left',
                    const='default',
                    help='Specify the list type: dict, list, left, found, multi, or log (defaults to left)')
parser.add_argument('-u', '--upload',
                    dest='upload',
                    help='upload plains from <UPLOAD>')
parser.add_argument('--version',
                    dest='version',
                    action='store_true',
                    help='display version and exit.')
parser.add_argument('-w', '--watch',
                    dest='watch',
                    action='store_true',
                    help='when uploading, watch for changes and continue uploading. This will use the value of delay between checks.')
parser.add_argument(
                    dest='LIST',
                    action='store',
                    nargs='*',
                    help='lists to target')
args = parser.parse_args()


############################################################
## Main App

def main():
  ## show lists
  if args.lists:
    lcapi.commands.show_lists()
    sys.exit(1)
  
  ## show version
  if args.version:
    print(f"lcapi v{pkg_resources.require('lcapi')[0].version}")
    sys.exit(1)

  ## if we set a delay param, override the config value
  if args.delay:
    config.delay = args.delay
  
  ## init our loop flag
  looped = False
  ## loop through our lists and process actions
  for ls in args.LIST:
    if looped and config.delay:
      ## if we already looped once and have a delay, wait
      time.sleep(float(config.delay))
    if args.download:
      ## download
      lcapi.commands.download(ls, args.type, args.outfile)
    elif args.upload:
      ## upload
      lcapi.commands.upload(ls, args.upload, args.watch)
    ## set our loop flag
    looped = True
if __name__ == "__main__":
  main()



import configparser
import os
import sys

############################################################
## Load configs

CONFIG_FILE=os.path.abspath(os.path.expanduser('~/.lcapirc'))
cp = configparser.ConfigParser()

## does our file exist?
if not os.path.exists(CONFIG_FILE):
  cp['default'] = { 'apikey': '',
    'url': '',
    'delay': 10 }
  with open(CONFIG_FILE, 'w') as configfile:
    cp.write(configfile)
else:
  cp.read(CONFIG_FILE)

## make sure we have a valid config
if not len(cp.sections()):
  print("Error: Bad config file! Check your .lcapirc")
  sys.exit(2)

## our config class
class Configs():
  key: str
  url: str
  delay: float
  lists: list

  def __init__(self):
    self.key = { 'apikey': cp.get('default', 'apikey') }
    self.url = cp.get('default', 'url')
    self.delay = float(cp.get('default', 'delay', fallback=10))
    if 'lists' in cp.sections():
      self.lists = cp['lists']
    else:
      self.lists = []

## init our config object and free the parser
config = Configs()
cp = None



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name='lcapi',
    version='0.9.6',
    description=(
        'A CLI client for the lc API.'
    ),
    url='https://github.com/unix-ninja/lcapi',
    author='unix-ninja',
    author_email='chris@unix-ninja.com',
    license='BSD',
    python_requires='>=3.9.0',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    include_package_data=True,
    entry_points={
        "console_scripts": [
             "lcapi=lcapi:main"
        ]
    },
    install_requires=[
        'requests'
        ]
    )
